@@ -2,7 +2,7 @@ package Test2::Harness::UI::RunProcessor;
 use strict;
 use warnings;
 
-our $VERSION = '0.000138';
+our $VERSION = '0.000139';
 
 use DateTime;
 use Data::GUID;
@@ -1103,7 +1103,7 @@ __END__
 
 =head1 NAME
 
-Test2::Harness::UI::Import
+Test2::Harness::UI::RunProcessor
 
 =head1 DESCRIPTION
 
